@@ -1,7 +1,7 @@
 /* gok-key.c
 *
-* Copyright 2001,2002 Sun Microsystems, Inc.,
-* Copyright 2001,2002 University Of Toronto
+* Copyright 2001-2009 Sun Microsystems, Inc.,
+* Copyright 2001-2009 University Of Toronto
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -24,7 +24,9 @@
 #endif
 
 #include <string.h>
-#include <gnome.h>
+#include <libgnome/gnome-program.h>
+#include <glib.h>
+#include <glib/gi18n.h>
 #include "gok-key.h"
 #include "gok-keyboard.h"
 #include "gok-mousecontrol.h"
@@ -56,8 +58,7 @@ gchar m_label[XkbKeyNameLength + 1];
 
 gint m_Group = 0; /* FIXME: statics are bad */
 
-#undef GOK_UTF8_DEBUG
-
+#ifdef GOK_UTF8_DEBUG
 static void 
 gok_key_print_utf8_debug (gchar *buf)
 {
@@ -82,6 +83,7 @@ gok_key_print_utf8_debug (gchar *buf)
       }
       fprintf (stderr, "\n");
 }
+#endif
 
 /* returned string must be freed */
 static gchar *
@@ -319,8 +321,6 @@ static unsigned int _numlock_mask = 0xFFFF;
 unsigned int
 gok_key_get_numlock_mask (Display *display)
 {
-	struct gok_modifier_keymask *m;
-
 	if (_numlock_mask == 0xFFFF) {
 		_numlock_mask = XkbKeysymToModifiers (display, XK_Num_Lock);
 	}
@@ -332,7 +332,6 @@ int
 gok_key_get_xkb_type_index (XkbDescPtr xkb, KeyCode keycode, guint group)
 {
 	int num_groups = XkbKeyNumGroups (xkb, keycode);
-	int index;
 	if (!xkb) 
 	        return 1;
 	if (group >= num_groups) 
@@ -421,9 +420,8 @@ static gchar *
 gok_key_label_from_keycode (KeyCode keycode, Display *display, guint level, guint group)
 {
   char buf[20];
-  int extra_rtn, nbytes, state = 0;
+  int extra_rtn, nbytes = 0;
   KeySym keysym = 0;
-  XkbStateRec xkb_state;
   long ucs;
   gunichar unichar;
 
@@ -504,7 +502,6 @@ gok_key_modifier_for_keycode (Display *display, XkbDescPtr xkb, int keycode)
 	guint group = gok_key_get_effective_group ();
 	gint type = gok_key_get_xkb_type_index (xkb, keycode, group);
 	guint modmask = 0;	
-	GokModifier *modifier;
         /* FIXME: assumes modifier bindings don't depend on current modmask! */
 	gint level = gok_key_level_for_type (display, gok_keyboard_get_xkb_desc (), type, &modmask);
 	KeySym keysym = XkbKeycodeToKeysym (display, (KeyCode) keycode, 
@@ -560,13 +557,11 @@ gok_key_from_xkb_key (GokKey *prevKey, GokKeyboard *pKeyboard, Display *display,
 {
   GokKey *pKey;
   gchar *label;
-  gchar name[XkbKeyNameLength + 1];
   gchar keycode_name[8];
   int keycode;
   XkbBoundsRec *pBounds;
-  int width, height, len;
+  int len;
   gboolean is_modifier = FALSE;
-  unsigned int numlock_mask;
   int group, level;
 
   pKey = gok_key_new (prevKey, NULL, pKeyboard);
@@ -826,11 +821,6 @@ gboolean gok_key_initialize (GokKey* pKey, xmlNode* pNode)
 	xmlNode* pNodeWrapperChild;
 	GokOutput* pNewOutput;
 	GokOutput* pOutputTemp;
-	gboolean settings_locked;
-	guint modmask =  
-		SPI_KEYMASK_SHIFT | SPI_KEYMASK_SHIFTLOCK | SPI_KEYMASK_ALT | 
-		SPI_KEYMASK_CONTROL | SPI_KEYMASK_MOD1 | SPI_KEYMASK_MOD2 | SPI_KEYMASK_MOD3 | SPI_KEYMASK_MOD4 |
-		SPI_KEYMASK_MOD5; /* ASSUMPTION: this includes numlock mask */
 	
 	g_assert (pKey != NULL);
 	g_assert (pNode != NULL);
@@ -1279,7 +1269,6 @@ GokKeyLabel* gok_keylabel_new (GokKey* pKey, gchar* pLabelText, guint level, gui
 
 	if (pLabelText != NULL)
 	{
-	        int len = strlen (pLabelText);
 		pNewLabel->Text = g_strdup (pLabelText);
 	}
 	
@@ -1520,7 +1509,6 @@ gok_key_get_image (GokKey* pKey)
 GtkWidget *
 gok_key_status_image (GokKey *key) 
 {
-	GokUIState state = key->ComponentState;
 	GtkWidget *image = NULL;
 	gchar *icon_name, *file;
 
@@ -1610,8 +1598,6 @@ gok_key_create_image_widget (GokKey* pKey)
 gchar* gok_key_get_label (GokKey* pKey)
 {
 	gchar* pTextReturned;
-	gchar* pToken;
-	gchar buffer[150];
 	GokKeyLabel* pKeyLabel;
 	gboolean bFoundLabel;
 	int  type = XkbAlphabeticIndex, keycode;
@@ -1927,7 +1913,7 @@ gok_key_update_toggle_state (GokKey *pKey)
 		if (pKey->ComponentState.radio) {
 			GOK_BUTTON (pKey->pButton)->indicator_type = /*g_strdup( ?*/ "radiobutton" /*)*/;
 		}
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (pKey->pButton),
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pKey->pButton),
 					      is_active);
 	}
 	gok_log_leave();
