@@ -159,7 +159,7 @@ static void gok_libusb_display_error(gchar *error)
 {
 	gchar *libusb_error = g_malloc0(256);
 	g_sprintf(libusb_error, _("can't initialize the libusb backend - %s"), error);
-	gok_main_display_error(libusb_error);
+	gok_main_display_fatal_error(libusb_error);
 	g_free(libusb_error);
 }
 
