@@ -33,6 +33,7 @@
 #endif
 
 #include <locale.h>
+#include <libgnome/gnome-macros.h>
 
 #include "gok-word-complete.h"
 #include "gok-keyslotter.h"
@@ -226,6 +227,8 @@ gok_wordcomplete_process_unichar (GokWordComplete *complete, gunichar letter)
 	GokWordCompleteClass *klass = GOK_WORDCOMPLETE_GET_CLASS (complete);
 	if (klass->process_unichar)
 		return (* klass->process_unichar) (complete, letter);
+	else
+		return NULL;
 }
 
 /**
@@ -291,6 +294,8 @@ gok_wordcomplete_predict (GokWordComplete *complete, gint num_predictions)
 	GokWordCompleteClass *klass = GOK_WORDCOMPLETE_GET_CLASS (complete);
 	if (klass->predict)
 	    return (* klass->predict) (complete, num_predictions);
+	else
+	    return NULL;
 }
 
 /**
