@@ -24,7 +24,7 @@
 #  include <config.h>
 #endif
 
-#include <gnome.h>
+#include <libgnomeui/libgnomeui.h>
 #include "gok-feedback.h"
 #include "gok-log.h"
 
