@@ -29,7 +29,7 @@
 #include <string.h>
 #include <stdlib.h>
 #include <ctype.h>
-#include <gnome.h>
+#include <libgnome/gnome-macros.h>
 #include "word-complete.h"
 #include "gok-log.h"
 
